@@ -172,7 +172,6 @@ class Client:
                 utils.write_file(test_file, config.test)
                 command = ["singularity", "exec", sif, "/bin/bash", test_file]
                 result = utils.run_command(command)
-                # result = subprocess.call(command)
 
                 # We can't run on incompatible hosts
                 if (
@@ -215,6 +214,12 @@ class Client:
         """
         raise NotImplementedError
 
+    def docgen(self, module_name):
+        """
+        Render documentation for a module.
+        """
+        raise NotImplementedError
+
     def show(self, name, names_only=False, out=None):
         """
         Show available packages
